@@ -1,5 +1,5 @@
 package Text::Autoformat;
-$Text::Autoformat::VERSION = '1.72';
+$Text::Autoformat::VERSION = '1.73';
 use 5.006;
 use strict;
 use warnings;
@@ -1262,7 +1262,7 @@ The Text::Reform module
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Text-Autoformat>
+L<https://github.com/neilb/Text-Autoformat>
 
 =head1 AUTHOR
 
